==> coventry-0.8.1.tar.gz: coventry-0.8.1/src/server.hpp <==
/*
 * Copyright (C) 2020 Tycho Softworks.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SERVER_HPP_
#define SERVER_HPP_

#ifdef __clang__
#pragma clang diagnostic ignored "-Wpadded"
#pragma clang diagnostic ignored "-Wswitch-enum"
#pragma clang diagnostic ignored "-Wweak-vtables"
#pragma clang diagnostic ignored "-Wunused-member-function"
#endif

#ifdef __GNUC__
#pragma GCC diagnostic ignored "-Wunused-result"
#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
#endif

#if __cplusplus < 201703L
#error C++17 compliant compiler required
#endif

#include <atomic>
#include <cassert>

#include <unistd.h>

#include "config.hpp"

namespace tycho {
template<typename T>
inline auto is(const T& object) {
    return object.operator bool();
}

class keyfile;
} // end namespace

using namespace tycho;

namespace server {
extern std::atomic<bool> running;
extern std::atomic<bool> exiting;
extern bool ipv6;
} // end namespace
#endif

==> coventry-0.8.6.tar.gz: coventry-0.8.6/src/server.hpp <==
/*
 * Copyright (C) 2020 Tycho Softworks.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SERVER_HPP_
#define SERVER_HPP_

#ifdef __clang__
#pragma clang diagnostic ignored "-Wpadded"
#pragma clang diagnostic ignored "-Wswitch-enum"
#pragma clang diagnostic ignored "-Wweak-vtables"
#pragma clang diagnostic ignored "-Wunused-member-function"
#endif

#ifdef __GNUC__
#pragma GCC diagnostic ignored "-Wunused-result"
#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
#endif

#if __cplusplus < 201703L
#error C++17 compliant compiler required
#endif

#include <moderncli/templates.hpp>
#include <moderncli/print.hpp>

#include <atomic>
#include <cassert>

#include "config.hpp"       // IWYU pragma: keep

using namespace tycho;

namespace server {
extern std::atomic<bool> running;
extern std::atomic<bool> exiting;
extern system_logger logger;
extern void logger_notify(const std::string& msg, const char *type);
extern bool ipv6;
} // end namespace
#endif
